@@ -1,14 +1,16 @@
 import numpy as np
 
-from .dispatch import (
+from dask.array.dispatch import (
     concatenate_lookup,
     divide_lookup,
     einsum_lookup,
     empty_lookup,
+    percentile_lookup,
     tensordot_lookup,
 )
-from .numpy_compat import divide as np_divide
-from .numpy_compat import ma_divide
+from dask.array.numpy_compat import divide as np_divide
+from dask.array.numpy_compat import ma_divide
+from dask.array.percentile import _percentile
 
 concatenate_lookup.register((object, np.ndarray), np.concatenate)
 tensordot_lookup.register((object, np.ndarray), np.tensordot)
@@ -19,6 +21,11 @@ divide_lookup.register((object, np.ndarray), np_divide)
 divide_lookup.register(np.ma.masked_array, ma_divide)
 
 
+@percentile_lookup.register(np.ndarray)
+def percentile(a, q, method="linear"):
+    return _percentile(a, q, method)
+
+
 @concatenate_lookup.register(np.ma.masked_array)
 def _concatenate(arrays, axis=0):
     out = np.ma.concatenate(arrays, axis=axis)
@@ -108,12 +115,11 @@ def _tensordot(a, b, axes=2):
 def register_cupy():
     import cupy
 
-    from dask.dataframe.backends import percentile
-    from dask.dataframe.dispatch import percentile_dispatch
+    from dask.array.dispatch import percentile_lookup
 
     concatenate_lookup.register(cupy.ndarray, cupy.concatenate)
     tensordot_lookup.register(cupy.ndarray, cupy.tensordot)
-    percentile_dispatch.register(cupy.ndarray, percentile)
+    percentile_lookup.register(cupy.ndarray, percentile)
 
     @einsum_lookup.register(cupy.ndarray)
     def _cupy_einsum(*args, **kwargs):
